==> CGAL-6.1-doc_html.tar.xz: doc_html/Number_types/annotated.js <==
var annotated =
[
    [ "CGAL", null, [
      [ "Gmpfi", "classCGAL_1_1Gmpfi.html", "classCGAL_1_1Gmpfi" ],
      [ "Gmpfr", "classCGAL_1_1Gmpfr.html", "classCGAL_1_1Gmpfr" ],
      [ "Gmpq", "classCGAL_1_1Gmpq.html", "classCGAL_1_1Gmpq" ],
      [ "Gmpz", "classCGAL_1_1Gmpz.html", "classCGAL_1_1Gmpz" ],
      [ "Gmpzf", "classCGAL_1_1Gmpzf.html", "classCGAL_1_1Gmpzf" ],
      [ "Interval_nt", "classCGAL_1_1Interval__nt.html", "classCGAL_1_1Interval__nt" ],
      [ "Is_valid", "classCGAL_1_1Is__valid.html", "classCGAL_1_1Is__valid" ],
      [ "Lazy_exact_nt", "classCGAL_1_1Lazy__exact__nt.html", "classCGAL_1_1Lazy__exact__nt" ],
      [ "Max", "structCGAL_1_1Max.html", "structCGAL_1_1Max" ],
      [ "Min", "structCGAL_1_1Min.html", "structCGAL_1_1Min" ],
      [ "MP_Float", "classCGAL_1_1MP__Float.html", "classCGAL_1_1MP__Float" ],
      [ "Mpzf", "structCGAL_1_1Mpzf.html", "structCGAL_1_1Mpzf" ],
      [ "NT_converter", "structCGAL_1_1NT__converter.html", "structCGAL_1_1NT__converter" ],
      [ "Number_type_checker", "classCGAL_1_1Number__type__checker.html", "classCGAL_1_1Number__type__checker" ],
      [ "Protect_FPU_rounding", "structCGAL_1_1Protect__FPU__rounding.html", "structCGAL_1_1Protect__FPU__rounding" ],
      [ "Quotient", "classCGAL_1_1Quotient.html", "classCGAL_1_1Quotient" ],
      [ "Rational_traits", "classCGAL_1_1Rational__traits.html", "classCGAL_1_1Rational__traits" ],
      [ "Root_of_traits", "structCGAL_1_1Root__of__traits.html", "structCGAL_1_1Root__of__traits" ],
      [ "Set_ieee_double_precision", "classCGAL_1_1Set__ieee__double__precision.html", "classCGAL_1_1Set__ieee__double__precision" ],
      [ "Sqrt_extension", "classCGAL_1_1Sqrt__extension.html", "classCGAL_1_1Sqrt__extension" ]
    ] ],
    [ "CORE", "namespaceCORE.html", [
      [ "BigFloat", "classCORE_1_1BigFloat.html", null ],
      [ "BigInt", "classCORE_1_1BigInt.html", null ],
      [ "BigRat", "classCORE_1_1BigRat.html", null ],
      [ "Expr", "classCORE_1_1Expr.html", null ]
    ] ],
    [ "leda_bigfloat", "classleda__bigfloat.html", null ],
    [ "leda_integer", "classleda__integer.html", null ],
    [ "leda_rational", "classleda__rational.html", null ],
    [ "leda_real", "classleda__real.html", null ],
    [ "mpq_class", "classmpq__class.html", null ],
    [ "mpz_class", "classmpz__class.html", null ],
    [ "RootOf_2", "classRootOf__2.html", "classRootOf__2" ]
];

==> CGAL-6.1.1-doc_html.tar.xz: doc_html/Number_types/annotated.js <==
var annotated =
[
    [ "boost", "namespaceboost.html", [
      [ "multiprecision", "namespaceboost_1_1multiprecision.html", [
        [ "cpp_int", "classboost_1_1multiprecision_1_1cpp__int.html", null ],
        [ "cpp_rational", "classboost_1_1multiprecision_1_1cpp__rational.html", null ],
        [ "gmp_int", "classboost_1_1multiprecision_1_1gmp__int.html", null ],
        [ "gmp_rational", "classboost_1_1multiprecision_1_1gmp__rational.html", null ]
      ] ]
    ] ],
    [ "CGAL", null, [
      [ "Gmpfi", "classCGAL_1_1Gmpfi.html", "classCGAL_1_1Gmpfi" ],
      [ "Gmpfr", "classCGAL_1_1Gmpfr.html", "classCGAL_1_1Gmpfr" ],
      [ "Gmpq", "classCGAL_1_1Gmpq.html", "classCGAL_1_1Gmpq" ],
      [ "Gmpz", "classCGAL_1_1Gmpz.html", "classCGAL_1_1Gmpz" ],
      [ "Gmpzf", "classCGAL_1_1Gmpzf.html", "classCGAL_1_1Gmpzf" ],
      [ "Interval_nt", "classCGAL_1_1Interval__nt.html", "classCGAL_1_1Interval__nt" ],
      [ "Is_valid", "classCGAL_1_1Is__valid.html", "classCGAL_1_1Is__valid" ],
      [ "Lazy_exact_nt", "classCGAL_1_1Lazy__exact__nt.html", "classCGAL_1_1Lazy__exact__nt" ],
      [ "Max", "structCGAL_1_1Max.html", "structCGAL_1_1Max" ],
      [ "Min", "structCGAL_1_1Min.html", "structCGAL_1_1Min" ],
      [ "MP_Float", "classCGAL_1_1MP__Float.html", "classCGAL_1_1MP__Float" ],
      [ "Mpzf", "structCGAL_1_1Mpzf.html", "structCGAL_1_1Mpzf" ],
      [ "NT_converter", "structCGAL_1_1NT__converter.html", "structCGAL_1_1NT__converter" ],
      [ "Number_type_checker", "classCGAL_1_1Number__type__checker.html", "classCGAL_1_1Number__type__checker" ],
      [ "Protect_FPU_rounding", "structCGAL_1_1Protect__FPU__rounding.html", "structCGAL_1_1Protect__FPU__rounding" ],
      [ "Quotient", "classCGAL_1_1Quotient.html", "classCGAL_1_1Quotient" ],
      [ "Rational_traits", "classCGAL_1_1Rational__traits.html", "classCGAL_1_1Rational__traits" ],
      [ "Root_of_traits", "structCGAL_1_1Root__of__traits.html", "structCGAL_1_1Root__of__traits" ],
      [ "Set_ieee_double_precision", "classCGAL_1_1Set__ieee__double__precision.html", "classCGAL_1_1Set__ieee__double__precision" ],
      [ "Sqrt_extension", "classCGAL_1_1Sqrt__extension.html", "classCGAL_1_1Sqrt__extension" ]
    ] ],
    [ "CORE", "namespaceCORE.html", [
      [ "BigFloat", "classCORE_1_1BigFloat.html", null ],
      [ "BigInt", "classCORE_1_1BigInt.html", null ],
      [ "BigRat", "classCORE_1_1BigRat.html", null ],
      [ "Expr", "classCORE_1_1Expr.html", null ]
    ] ],
    [ "leda_bigfloat", "classleda__bigfloat.html", null ],
    [ "leda_integer", "classleda__integer.html", null ],
    [ "leda_rational", "classleda__rational.html", null ],
    [ "leda_real", "classleda__real.html", null ],
    [ "mpq_class", "classmpq__class.html", null ],
    [ "mpz_class", "classmpz__class.html", null ],
    [ "RootOf_2", "classRootOf__2.html", "classRootOf__2" ]
];
